pub fn bpf_probe_read(dst: &mut [u8], src: &[u8]) -> LinuxResult<()>Expand description
For tracing programs, safely attempt to read size bytes from kernel space address unsafe_ptr and store the data in dst.
pub fn bpf_probe_read(dst: &mut [u8], src: &[u8]) -> LinuxResult<()>For tracing programs, safely attempt to read size bytes from kernel space address unsafe_ptr and store the data in dst.