pub fn probe_read_user_str<F: KernelAuxiliaryOps>(
dst: &mut [u8],
src: *const u8,
) -> LinuxResult<usize>Expand description
Copy a NULL terminated string from an unsafe user address unsafe_ptr to dst.
pub fn probe_read_user_str<F: KernelAuxiliaryOps>(
dst: &mut [u8],
src: *const u8,
) -> LinuxResult<usize>Copy a NULL terminated string from an unsafe user address unsafe_ptr to dst.