Module map

Module map 

BPF map implementations.

Structs

BpfMapGetNextKeyArg
Arguments for BPF map get next key operations.
BpfMapMeta
Metadata for a BPF map.
BpfMapUpdateArg
Arguments for BPF map update operations.
BpfMapUpdateElemFlags
flags for BPF_MAP_UPDATE_ELEM command
UnifiedMap
A unified BPF map that can hold any type of BPF map.

Traits

BpfMapCommonOps
Common operations for BPF maps.
PerCpuVariants
PerCpuVariants is a trait for per-cpu data structures.
PerCpuVariantsOps
Operations for per-cpu variants.

Functions

bpf_lookup_elem
Look up an element by key in a specified map and return its value.
bpf_map_create
Create a map and return a file descriptor that refers to the map. The close-on-exec file descriptor flag is automatically enabled for the new file descriptor.
bpf_map_delete_elem
Look up and delete an element by key in a specified map.
bpf_map_freeze
Freeze a map to prevent further modifications.
bpf_map_get_next_key
Look up an element by key in a specified map and return the key of the next element.
bpf_map_lookup_and_delete_elem
Look up an element with the given key in the map referred to by the file descriptor fd, and if found, delete the element.
bpf_map_lookup_batch
Iterate and fetch multiple elements in a map.
bpf_map_update_elem
Create or update an element (key/value pair) in a specified map.

Type Aliases

BpfCallBackFn
Callback function type for iterating over map elements.