pub fn bpf_map_create<F: KernelAuxiliaryOps, T: PerCpuVariantsOps + 'static>(
map_meta: BpfMapMeta,
poll_waker: Option<Arc<dyn PollWaker>>,
) -> BpfResult<UnifiedMap>Expand description
Create a map and return a file descriptor that refers to the map. The close-on-exec file descriptor flag is automatically enabled for the new file descriptor.
See https://ebpf-docs.dylanreimerink.nl/linux/syscall/BPF_MAP_CREATE/