pub fn bpf_map_get_next_key<F: KernelAuxiliaryOps>(
arg: BpfMapGetNextKeyArg,
) -> BpfResult<()>Expand description
Look up an element by key in a specified map and return the key of the next element.
- If key is
None, the operation returns zero and sets the next_key pointer to the key of the first element. - If key is
Some(T), the operation returns zero and sets the next_key pointer to the key of the next element. - If key is the last element, returns -1 and errno is set to ENOENT.
See https://ebpf-docs.dylanreimerink.nl/linux/syscall/BPF_MAP_GET_NEXT_KEY/