pub struct BpfProgVerifierInfo {
pub log_level: VerifierLogLevel,
pub _log_buf_size: u32,
pub _log_buf_ptr: usize,
}Expand description
BPF program verifier information.
Fields
log_level: VerifierLogLevelThis attribute specifies the level/detail of the log output. Valid values are.
_log_buf_size: u32This attributes indicates the size of the memory region in bytes
indicated by log_buf which can safely be written to by the kernel.
_log_buf_ptr: usizeThis attributes can be set to a pointer to a memory region allocated/reservedby the loader process where the verifier log will be written to. The detail of the log is set by log_level. The verifier log is often the only indication in addition to the error code of why the syscall command failed to load the program.
The log is also written to on success. If the kernel runs out of space in the buffer while loading, the loading process will fail and the command will return with an error code of -ENOSPC. So it is important to correctly size the buffer when enabling logging.