pub struct EBPFPreProcessor { /* private fields */ }Expand description
eBPF preprocessor for relocating map file descriptors in eBPF instructions.
Implementations
Sourceimpl EBPFPreProcessor
impl EBPFPreProcessor
Sourcepub fn preprocess<F: KernelAuxiliaryOps>(
instructions: Vec<u8>,
) -> LinuxResult<Self>
pub fn preprocess<F: KernelAuxiliaryOps>( instructions: Vec<u8>, ) -> LinuxResult<Self>
Preprocess the instructions to relocate the map file descriptors.
Sourcepub fn get_new_insn(&self) -> &Vec<u8> ⓘ
pub fn get_new_insn(&self) -> &Vec<u8> ⓘ
Get the new instructions after preprocessing.
Sourcepub fn get_raw_file_ptr(&self) -> &Vec<usize>
pub fn get_raw_file_ptr(&self) -> &Vec<usize>
Get the raw file pointer after preprocessing. The raw file pointer is a list of pointers to the maps that are used in the program. The pointers are used to access the maps in the program.