pub unsafe extern "C" fn printf(
w: &mut impl Write,
str: *const c_char,
...
) -> c_intExpand description
Printf according to the format string, function will return the number of bytes written(including ‘\0’)
Safety
The caller must ensure that the format string and arguments are valid.