pub fn raw_map_for_each_elem<F: KernelAuxiliaryOps>(
map: *mut c_void,
cb: *const c_void,
ctx: *const c_void,
flags: u64,
) -> i64Expand description
For each element in map, call callback_fn function with map, callback_ctx and other map-specific parameters. The callback_fn should be a static function and the callback_ctx should be a pointer to the stack. The flags is used to control certain aspects of the helper. Currently, the flags must be 0.
The following are a list of supported map types and their respective expected callback signatures:
- BPF_MAP_TYPE_HASH
- BPF_MAP_TYPE_PERCPU_HASH
- BPF_MAP_TYPE_LRU_HASH
- BPF_MAP_TYPE_LRU_PERCPU_HASH
- BPF_MAP_TYPE_ARRAY
- BPF_MAP_TYPE_PERCPU_ARRAY
long (*callback_fn)(struct bpf_map *map, const void key, void *value, void *ctx);
For per_cpu maps, the map_value is the value on the cpu where the bpf_prog is running.