trace_printf

Function trace_printf 

pub fn trace_printf<F: KernelAuxiliaryOps>(
    fmt_ptr: u64,
    fmt_len: u64,
    arg3: u64,
    arg4: u64,
    arg5: u64,
) -> i64
See https://ebpf-docs.dylanreimerink.nl/linux/helper-function/bpf_trace_printk/

Warning

The arg3, arg4, and arg5 parameters are pointers to the stack, so we first read the value they point to before passing them to the printf function.