BPF map implementations.
Structs
- BpfMap
GetNext KeyArg - Arguments for BPF map get next key operations.
- BpfMap
Meta - Metadata for a BPF map.
- BpfMap
Update Arg - Arguments for BPF map update operations.
- BpfMap
Update Elem Flags - flags for BPF_MAP_UPDATE_ELEM command
- Unified
Map - A unified BPF map that can hold any type of BPF map.
Traits
- BpfMap
Common Ops - Common operations for BPF maps.
- PerCpu
Variants - PerCpuVariants is a trait for per-cpu data structures.
- PerCpu
Variants Ops - Operations for per-cpu variants.
Functions
- bpf_
lookup_ elem - Look up an element by key in a specified map and return its value.
- bpf_
map_ create - Create a map and return a file descriptor that refers to the map. The close-on-exec file descriptor flag is automatically enabled for the new file descriptor.
- bpf_
map_ delete_ elem - Look up and delete an element by key in a specified map.
- bpf_
map_ freeze - Freeze a map to prevent further modifications.
- bpf_
map_ get_ next_ key - Look up an element by key in a specified map and return the key of the next element.
- bpf_
map_ lookup_ and_ delete_ elem - Look up an element with the given key in the map referred to by the file descriptor fd, and if found, delete the element.
- bpf_
map_ lookup_ batch - Iterate and fetch multiple elements in a map.
- bpf_
map_ update_ elem - Create or update an element (key/value pair) in a specified map.
Type Aliases
- BpfCall
Back Fn - Callback function type for iterating over map elements.