pub fn bpf_map_delete_elem<F: KernelAuxiliaryOps>(
arg: BpfMapUpdateArg,
) -> LinuxResult<()>Expand description
Look up and delete an element by key in a specified map.
WARN
Not all map types (particularly array maps) support this operation, instead a zero value can be written to the map value. Check the map types page to check for support.
See https://ebpf-docs.dylanreimerink.nl/linux/syscall/BPF_MAP_DELETE_ELEM/